var gulp = require('gulp');
var watch = require('gulp-watch');
var cleanCSS = require('gulp-clean-css');
var autoprefixer = require('gulp-autoprefixer');
var uglify = require('gulp-uglify');
var browserSync = require('browser-sync').create();
var reload = browserSync.reload;
var changed = require('gulp-changed');
var copy = require('gulp-copy');
var notify = require("gulp-notify");
// 图片压缩
var imagemin = require('gulp-imagemin'),
    pngquant = require('imagemin-pngquant'), //深度压缩
    cache = require('gulp-cache');

// 压缩JS
gulp.task('compress', function (cb) {
    var entryPath = './src/js/**/*.js',
        outputPath = './dist/js';

    return gulp.src(entryPath)
        .pipe(watch(entryPath))
        .pipe(uglify())
        .pipe(changed(outputPath))
        .pipe(gulp.dest(outputPath))
        .pipe(reload({
            stream: true
        }))
        .pipe(notify({
            message: 'compress task complete'
        }));
});

// 压缩图片
gulp.task('imagemin', function () {
    var entryPath = ['./src/images/**/*.{png,jpg,gif,ico}', './src/images/*.{png,jpg,gif,ico}'],
        outputPath = './dist/images';

    return gulp.src(entryPath)
        .pipe(watch(entryPath))
        .pipe(cache(imagemin({
            progressive: true,
            svgoPlugins: [{
                removeViewBox: false
            }],
            use: [pngquant()]
        })))
        .pipe(changed(outputPath))
        .pipe(gulp.dest(outputPath))
        .pipe(notify({
            message: 'imagemin task complete'
        }));


});


// 压缩css
gulp.task('cleanCSS', function () {
    var entryPath = ['./src/css/*.css', './src/css/**/*.css'],
        outputPath = './dist/css';

    return gulp.src(entryPath)
        .pipe(watch(entryPath))
        .pipe(autoprefixer({
            browsers: ['> 5% in alt-AS'],
            cascade: false
        }))
        .pipe(cache(cleanCSS({
            inline: ['remote'],
            advanced: false, //类型：Boolean 默认：true [是否开启高级优化（合并选择器等）]
            keepBreaks: true, //类型：Boolean 默认：false [是否保留换行]
            keepSpecialComments: '*'
            //保留所有特殊前缀 当你用autoprefixer生成的浏览器前缀，如果不加这个参数，有可能将会删除你的部分前缀
        })))
        .pipe(changed(outputPath))
        .pipe(gulp.dest(outputPath))
        .pipe(notify({
            message: 'cleanCSS task complete'
        }));


});

// 复制目录
gulp.task('copy', function () {
    var entryPath = './src/html/**/*.*',
        outputPath = './dist/html/';

    return gulp.src(entryPath)
        .pipe(watch(entryPath))
        .pipe(changed(outputPath))
        .pipe(gulp.dest(outputPath))
        .pipe(notify({
            message: 'copy task complete'
        }));
});


// server
// gulp.task('browserSync', function() {

//     browserSync.init({
//         server: "./dist/"
//     });

//     gulp.watch("./src/js/**/*.js", ['compress']);
//     gulp.watch("./src/images/*.{png,jpg,gif,ico}", ['imagemin']);
//     gulp.watch("./src/unpackage/res/**/*.{png,jpg,gif,ico}", ['unpackage']);
//     gulp.watch("./src/css/*.css", ['cleanCSS']);
//     gulp.watch(['./html/**/*.html'],['copy']);
//     gulp.watch("./dist/html/**/*.html").on('change', browserSync.reload);

// });

//监听文件改变
gulp.task('watch', function () {
    gulp.watch('./src/js/**/*.js', ['compress']);
    gulp.watch('./src/css/*.css', ['cleanCSS']);
    gulp.watch('./src/html/**/*.html', ['copy']);
    gulp.watch(['./src/images/**/*.{png,jpg,gif,ico}'], ['imagemin']);
})


//启动默认任务即可监听所有文件的修改并执行相应任务
gulp.task('default', ['watch']);

gulp.task('tasks', ['compress','cleanCSS','copy','watch']);

